index API documentation
Description: ## What Problem Does sofine solve? You need to get data related to a set of keys from many sources:...

`

## Developing sofine

The README documentation covers the very common case of using sofine as a library to manage and call your own plugins and use them in your own applications.

However, you might want to develop with `sofine` more directly. Perhaps you want to just use the simple plugin loading mechanism in `sofine/lib/utils/utils.py` or want to fork the project to add features or integrate it with another project. Here is how to get started.

## Install Dependencies

To run the `make docs` target to build updated documentation in the `docs` directory, you may need to install two dependencies.

    pip install mako
    pip install markdown

To support using the plugins in `PROJECT_ROOT/sofine/plugins/examples` and running the tests in `PROJECT_ROOT/tests/*_examples.py`:

    easy_install mechanize
    easy_install beautifulsoup4
    pip install ystockquote

## make Targets

To run core unit tests on OSX/Linux: `make test`, on Windows: `test.bat`

To run unit tests on the example plugins on OSX/Linux: `make test_examples`, on Windows `test_examples.bat`

## Complete Code Documentation

Command Runners
runner
rest_runner

Plugins
plugin_base
standard/file_source
example/ystockquotelib
example/google_search_results
example/fidelity
example/archive_dot_org_search_results
mock/ystockquotelib

Tests

NOTE: Tests for fidelity example plugin must be run manually, because this plugin requires arguments that contain sensitive data

tests/test_runner_from_rest
tests/`test_runner_from_py_examples
tests/test_runner_from_py
tests/test_runner_from_cli_examples
tests/test_runner_from_cli

Utils and Conf
lib/utils
lib/conf

Documentation generated by `pdoc` 0.2.4. pdoc is in the public domain with the UNLICENSE.